@@ -1,7 +1,7 @@
 package App::LintPrereqs;
 
 our $DATE = '2015-08-18'; # DATE
-our $VERSION = '0.29'; # VERSION
+our $VERSION = '0.30'; # VERSION
 
 use 5.010001;
 use strict;
@@ -54,7 +54,7 @@ sub _scan_prereqs {
         sub {
             return unless -f;
             return if check_backup_filename(filename=>$_);
-            return unless /\.t$/;
+            return unless /\.(t|pl|pm)$/;
             push @files, "$File::Find::dir/$_";
         },
         (grep {-d} (
@@ -326,7 +326,7 @@ App::LintPrereqs - Check extraneous/missing prerequisites in dist.ini
 
 =head1 VERSION
 
-This document describes version 0.29 of App::LintPrereqs (from Perl distribution App-LintPrereqs), released on 2015-08-18.
+This document describes version 0.30 of App::LintPrereqs (from Perl distribution App-LintPrereqs), released on 2015-08-18.
 
 =head1 SYNOPSIS
 
